translate.convert.po2tmx.po2tmx

Package translate :: Package convert :: Module po2tmx :: Class po2tmx |
[hide private]
[frames] | no frames]

# Class po2tmx

source code

Instance Methods | [hide private]
convertfile(self, inputfile, sourcelanguage='en', targetlanguage=None) converts a .po file to TMX file | source code
convertfiles(self, inputfile, tmxfile, sourcelanguage='en', targetlanguage=None) converts a .po file (possibly many) to TMX file | source code